pub struct AsyncValue<K, T, E>(/* private fields */);Expand description
A declaration of one read. All changing request inputs belong in key.
Loader execution is untracked and uses the supplied local executor. Reads
participate when reached by a boundary, not merely when declared.
Implementations
Sourceimpl<K: Clone + PartialEq + 'static, T: 'static, E: Display + 'static> AsyncValue<K, T, E>
impl<K: Clone + PartialEq + 'static, T: 'static, E: Display + 'static> AsyncValue<K, T, E>
pub fn new<F: Future<Output = Result<T, E>> + 'static>( owner: &OwnerHandle, key: impl Fn() -> K + 'static, load: impl Fn(K, CancellationToken) -> F + 'static, spawn: impl Fn(LocalBoxFuture<'static, ()>) + 'static, ) -> Self